Module: deluge
Branch: master
Commit: 672668ccdbffc307b87c0c992b2da1febb61b4b9

Author: Damien Churchill <[email protected]>
Date:   Fri Jun 11 15:59:33 2010 +0100

change bits to bytes, thanks to charles

---

 deluge/ui/web/js/deluge-all/Formatters.js |    6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/deluge/ui/web/js/deluge-all/Formatters.js 
b/deluge/ui/web/js/deluge-all/Formatters.js
index ed36bfe..face943 100644
--- a/deluge/ui/web/js/deluge-all/Formatters.js
+++ b/deluge/ui/web/js/deluge-all/Formatters.js
@@ -84,12 +84,12 @@ Deluge.Formatters = {
        /**
         * Formats a string to display a transfer speed utilizing {...@link 
#size}
         *
         * @param {Number} bits the number of bits per second
         * @param {Boolean} showZero pass in true to displays 0 values
         * @return {String} formatted string with KiB, MiB or GiB units.
         */
-       speed: function(bits, showZero) {
-               return (!bits && !showZero) ? '' : fsize(bits, showZero) + '/s';
+       speed: function(bytes, showZero) {
+               return (!bytess && !showZero) ? '' : fsize(bytes, showZero) + 
'/s';
        },
        
@@ -84,12 +84,12 @@ Deluge.Formatters = {
#size}
         *
-        * @param {Number} bits the number of bits per second
+        * @param {Number} bytes the number of bytes per second
         * @param {Boolean} showZero pass in true to displays 0 values
         * @return {String} formatted string with KiB, MiB or GiB units.
        /**

-- 
You received this message because you are subscribed to the Google Groups 
"deluge-commit" group.
To post to this group, send email to [email protected].
To unsubscribe from this group, send email to 
[email protected].
For more options, visit this group at 
http://groups.google.com/group/deluge-commit?hl=en.

Reply via email to